pub unsafe extern "C" fn SDL_GameControllerTypeForIndex(
joystick_index: c_int,
) -> SDL_GameControllerTypeExpand description
Get the type of a game controller.
This can be called before any controllers are opened.
pub unsafe extern "C" fn SDL_GameControllerTypeForIndex(
joystick_index: c_int,
) -> SDL_GameControllerTypeGet the type of a game controller.
This can be called before any controllers are opened.