#[repr(transparent)]pub struct SDL_SensorID(pub i32);Expand description
This is a unique ID for a sensor for the time it is connected to the system.
It is never reused for the lifetime of the application.
The ID value starts at 0 and increments from there. The value -1 is an invalid ID.
Tuple Fields
0: i32Trait Implementations
Sourceimpl Clone for SDL_SensorID
impl Clone for SDL_SensorID
Sourcefn clone(&self) -> SDL_SensorID
fn clone(&self) -> SDL_SensorID
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for SDL_SensorID
impl Debug for SDL_SensorID
Sourceimpl Default for SDL_SensorID
impl Default for SDL_SensorID
Sourcefn default() -> SDL_SensorID
fn default() -> SDL_SensorID
Returns the “default value” for a type. Read more
Sourceimpl Hash for SDL_SensorID
impl Hash for SDL_SensorID
Sourceimpl Ord for SDL_SensorID
impl Ord for SDL_SensorID
Sourcefn cmp(&self, other: &SDL_SensorID) -> Ordering
fn cmp(&self, other: &SDL_SensorID) -> Ordering
1.21.0 (const: unstable) · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for SDL_SensorID
impl PartialEq for SDL_SensorID
Sourcefn eq(&self, other: &SDL_SensorID) -> bool
fn eq(&self, other: &SDL_SensorID) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl PartialOrd for SDL_SensorID
impl PartialOrd for SDL_SensorID
impl Copy for SDL_SensorID
impl Eq for SDL_SensorID
impl StructuralPartialEq for SDL_SensorID