pub unsafe extern "C" fn SDL_SetWindowHitTest(
window: *mut SDL_Window,
callback: SDL_HitTest,
callback_data: *mut c_void,
) -> c_intExpand description
Sets the hit test callback hit test user data for the window.
pub unsafe extern "C" fn SDL_SetWindowHitTest(
window: *mut SDL_Window,
callback: SDL_HitTest,
callback_data: *mut c_void,
) -> c_intSets the hit test callback hit test user data for the window.